@@ -23,7 +23,7 @@ import os
 
 os.environ["GST_DEBUG_DUMP_DOT_DIR"] = "/tmp"
 os.putenv('GST_DEBUG_DUMP_DIR_DIR', '/tmp')
-
+import which
 import time
 import transcoder_engine
 import gobject; gobject.threads_init()
@@ -70,7 +70,8 @@ supported_containers = [
         "MPEG4",
         "3GPP",
         "MXF",
-        "ASF"
+        "ASF",
+        "WebM"
 ]
 
 supported_audio_codecs = [
@@ -95,25 +96,27 @@ supported_video_codecs = [
        "mpeg4",
        "xvid",
        "h263p",
-       "wmv2"
+       "wmv2",
+       "vp8"
 ]
 
 # Maps containers to the codecs they support.  The first two elements are
 # "special" in that they are the default audio/video selections for that
 # container.
 supported_container_map = {
-    'Ogg':        [ 'vorbis', 'theora', 'flac', 'speex', 'celt', 'dirac' ],
+    'Ogg':        [ 'vorbis', 'theora', 'flac', 'speex', 'celt', 'dirac', 'vp8' ],
     'MXF':        [ 'mp3', 'h264', 'aac', 'ac3', 'mpeg2', 'mpeg4' ],
-    'Matroska':   [ 'flac', 'dirac', 'aac', 'ac3', 'theora', 'mp3', 'h264',
+    'Matroska':   [ 'flac', 'dirac', 'aac', 'ac3', 'theora', 'mp3', 'h264', 'vp8',
     'mpeg4', 'mpeg2', 'xvid', 'vorbis', 'h263p' ],
-    'AVI':        [ 'mp3', 'h264', 'dirac', 'ac3', 'mpeg2', 'mpeg4', 'xvid','wma2','wmv2' ],
-    'Quicktime':  [ 'aac', 'h264', 'ac3', 'dirac', 'mp3', 'mpeg2', 'mpeg4' ],
+    'AVI':        [ 'mp3', 'h264', 'dirac', 'ac3', 'mpeg2', 'mpeg4', 'xvid','wma2','wmv2', 'vp8' ],
+    'Quicktime':  [ 'aac', 'h264', 'ac3', 'dirac', 'mp3', 'mpeg2', 'mpeg4', 'vp8' ],
     'MPEG4':      [ 'aac', 'h264', 'mp3', 'mpeg2', 'mpeg4' ],
     '3GPP':       [ 'aac', 'h264', 'mp3', 'mpeg2', 'mpeg4','amrnb','h263p' ],
     'MPEG PS':    [ 'mp3', 'mpeg2', 'ac3', 'h264', 'aac', 'mpeg4' ],
     'MPEG TS':    [ 'mp3', 'h264', 'ac3', 'mpeg2', 'aac', 'mpeg4', 'dirac' ],
     'FLV':        [ 'mp3', 'h264' ],
-    'ASF':        [ 'wma2','wmv2','mp3']
+    'ASF':        [ 'wma2','wmv2','mp3'],
+    'WebM':       [ 'vorbis','vp8']
 }
 
 class TransmageddonUI:
@@ -125,8 +128,6 @@ class TransmageddonUI:
 
        self.builder = gtk.Builder()
 
-       self.builder.set_translation_domain("transmageddon")
-
        #Set the Glade file
        self.uifile = "transmageddon.ui"
        self.builder.add_from_file(self.uifile)
@@ -240,26 +241,17 @@ class TransmageddonUI:
 
        # Populate the Container format combobox
        self.lst = supported_containers
-       liststore = gtk.ListStore(gobject.TYPE_STRING)
        for i in self.lst:
-           liststore.append([i])
-       self.containerchoice.set_model(liststore)
-       cell = gtk.CellRendererText()
-       self.containerchoice.pack_start(cell, True)
-       self.containerchoice.add_attribute(cell, "text", 0)
+           self.containerchoice.append_text(i)
 
        # Populate the rotatation box
        self.rotationlist = [_("No rotation (default)"), _("Clockwise 90 degrees"), _("Rotate 180 degrees"), 
                            _("Counterclockwise 90 degrees"), _("Horizontal flip"),
                            _("Vertical flip"), _("Upper left diagonal flip"),
                            _("Upper right diagnonal flip") ]
-       liststore = gtk.ListStore(gobject.TYPE_STRING)
+
        for y in self.rotationlist: 
-           liststore.append([y])
-       self.rotationchoice.set_model(liststore)
-       cell = gtk.CellRendererText()
-       self.rotationchoice.pack_start(cell, True)
-       self.rotationchoice.add_attribute(cell, "text", 0)
+           self.rotationchoice.append_text(y)
 
        self.rotationchoice.set_active(0)
        self.rotationvalue = int(0) 
@@ -267,23 +259,17 @@ class TransmageddonUI:
        # Populate Device Presets combobox
        devicelist = []
        shortname = []
-       liststore = gtk.ListStore(gobject.TYPE_STRING)
-       for x, (name, device) in enumerate(sorted(presets.get().items(),
-                                   lambda x, y: cmp(x[1].make + x[1].model,
-                                                    y[1].make + y[1].model))):
-           liststore.append([str(device)])
+       preset_list = sorted(presets.get().items(),
+                            key = (lambda x: x[1].make + x[1].model))
+       for x, (name, device) in enumerate(preset_list):
+           self.presetchoice.append_text(str(device))
            devicelist.append(str(device))
            shortname.append(str(name))
 
        #for (name, device) in (presets.get().items()):
        #    shortname.append(str(name))
        self.presetchoices = dict(zip(devicelist, shortname))
-       liststore.prepend(["No Presets"])
-
-       self.presetchoice.set_model(liststore)
-       cell = gtk.CellRendererText()
-       self.presetchoice.pack_start(cell, True)
-       self.presetchoice.add_attribute(cell, "text", 0)
+       self.presetchoice.prepend_text(_("No Presets"))
 
        self.waiting_for_signal="False"
 
@@ -373,9 +359,12 @@ class TransmageddonUI:
                    }
                if percent_remain > 0.5:
                    if self.passcounter == int(0):
-                       self.ProgressBar.set_text(_("Estimated time remaining: ") + str(time_rem))
+                       self.ProgressBar.set_text(_("Estimated time remaining: %(time)s") % {'time': str(time_rem)})
                    else:
-                       self.ProgressBar.set_text(_("Pass " + str(self.passcounter) + " time remaining: ") + str(time_rem))
+                       self.ProgressBar.set_text(_("Pass %(count)d time remaining: %(time)s") % {
+                           'count': self.passcounter,
+                           'time': str(time_rem),
+                           })
                return True
            else:
                self.ProgressBar.set_fraction(0.0)
@@ -392,7 +381,7 @@ class TransmageddonUI:
    def _on_eos(self, source):
        context_id = self.StatusBar.get_context_id("EOS")
        if (self.multipass ==  False) or (self.passcounter == int(0)):
-           self.StatusBar.push(context_id, (_("File saved to ") + self.videodirectory))
+           self.StatusBar.push(context_id, (_("File saved to %(dir)s") % {'dir': self.videodirectory}))
            self.FileChooser.set_sensitive(True)
            self.containerchoice.set_sensitive(True)
            self.CodecBox.set_sensitive(True)
@@ -407,7 +396,7 @@ class TransmageddonUI:
            self.multipass = False
            self.passcounter = False
        else:
-           self.StatusBar.push(context_id, (_("Pass " + str(self.passcounter) + " Complete")))
+           self.StatusBar.push(context_id, (_("Pass %(count)d Complete") % {'count': self.passcounter}))
            self.start_time = False
            self.ProgressBar.set_text(_("Start next pass"))
            if self.passcounter == (self.multipass-1):
@@ -425,16 +414,16 @@ class TransmageddonUI:
        if d.is_video:
            self.videodata = { 'videowidth' : d.videowidth, 'videoheight' : d.videoheight, 'videotype' : d.inputvideocaps,
                               'videolenght' : d.videolength, 'fratenum' : d.videorate.num, 'frateden' :  d.videorate.denom }
-           self.videoinformation.set_markup(''.join(('<small>', 'Video width&#47;height: ', str(self.videodata['videowidth']), 
+           self.videoinformation.set_markup(''.join(('<small>', _('Video width&#47;height: '), str(self.videodata['videowidth']), 
                                             "x", str(self.videodata['videoheight']), '</small>')))
-           self.videocodec.set_markup(''.join(('<small>', 'Video codec: ', 
-                                       str(gst.pbutils.get_codec_description(self.videodata['videotype'])), 
+           self.videocodec.set_markup(''.join(('<small>', _('Video codec: %(codec)s') % {'codec':
+                                       str(gst.pbutils.get_codec_description(self.videodata['videotype']))},
                                       '</small>')))
        if d.is_audio:
            self.audiodata = { 'audiochannels' : d.audiochannels, 'samplerate' : d.audiorate, 'audiotype' : d.inputaudiocaps }
-           self.audioinformation.set_markup(''.join(('<small>', 'Audio channels: ', str(self.audiodata['audiochannels']), '</small>')))
-           self.audiocodec.set_markup(''.join(('<small>','Audio codec: ',
-                                      str(gst.pbutils.get_codec_description(self.audiodata['audiotype'])),'</small>')))
+           self.audioinformation.set_markup(''.join(('<small>', _('Audio channels: %(chans)s') % {'chans': str(self.audiodata['audiochannels'])}, '</small>')))
+           self.audiocodec.set_markup(''.join(('<small>', _('Audio codec: %(codec)s') % {'codec':
+                                      str(gst.pbutils.get_codec_description(self.audiodata['audiotype']))}, '</small>')))
        self.discover_done=True
        if self.waiting_for_signal == True:
            if self.containertoggle == True:
@@ -623,12 +612,12 @@ class TransmageddonUI:
        self.ContainerFormatSuffix = codecfinder.csuffixmap[container]
        self.outputfilename = str(self.nosuffix+self.timestamp+self.ContainerFormatSuffix)
        context_id = self.StatusBar.get_context_id("EOS")
-       self.StatusBar.push(context_id, (_("Writing " + self.outputfilename)))
+       self.StatusBar.push(context_id, (_("Writing %(filename)s") % {'filename': self.outputfilename}))
        if self.multipass == False:
            self.ProgressBar.set_text(_("Transcoding Progress"))
        else:
            self.passcounter=int(1)
-           self.ProgressBar.set_text(_("Pass " + str(self.passcounter) + " Progress"))
+           self.ProgressBar.set_text(_("Pass %(count)d Progress") % {'count': self.passcounter})
        if self.audiodata.has_key("samplerate"):
            self.check_for_elements()
            if self.missingtoggle==False:
@@ -757,9 +746,14 @@ class TransmageddonUI:
        if os.access(pngfile, os.F_OK):
            os.remove(pngfile)
        gst.DEBUG_BIN_TO_DOT_FILE (self._transcoder.pipeline, gst.DEBUG_GRAPH_SHOW_ALL, 'transmageddon-debug-graph')
-       print "The debug feature requires graphviz (dot) to be installed"
-       os.system("dot -Tpng -o /tmp/transmageddon-pipeline.png /tmp/transmageddon-debug-graph.dot")
-       gtk.show_uri(gtk.gdk.Screen(), "file:///tmp/transmageddon-pipeline.png", 0)
+       # check if graphviz is installed with a simple test
+       try:
+           dot = which.which("dot")
+           os.system(dot + " -Tpng -o " + pngfile + " " + dotfile)
+           gtk.show_uri(gtk.gdk.Screen(), "file://"+pngfile, 0)
+       except which.WhichError:
+              print "The debug feature requires graphviz (dot) to be installed."
+              print "Transmageddon can not find the (dot) binary."
 
 if __name__ == "__main__":
         hwg = TransmageddonUI()
